@@ -115,20 +115,9 @@ sub provides {
 	    local $SIG{__WARN__} = sub {};
 	    $manifest = ExtUtils::Manifest::maniread();
 	}
-	keys %{ $manifest }
+	keys %{ $manifest || {} }
 	    or return;
 
-	# The Module::Metadata docs say not to use
-	# package_versions_from_directory() directly, but the 'files =>'
-	# version of provides() is broken, and has been known to be so
-	# since 2014, so it's not getting fixed any time soon. So:
-
-	my @files = grep { m/ [.] pm \z /smx } keys %{ $manifest };
-	$provides = Module::Metadata->package_versions_from_directory(
-	    undef,
-	    \@files,
-	);
-
 	# Skeleton so we can use should_index_file() and
 	# should_index_package().
 	my $meta = CPAN::Meta->new( {
@@ -138,12 +127,21 @@ sub provides {
 	    },
 	);
 
-	foreach my $pkg ( keys %{ $provides } ) {
-	    $meta->should_index_package( $pkg )
-		and $meta->should_index_file(
-		    $provides->{$pkg}{file} )
-		and next;
-	    delete $provides->{$pkg};
+	# The Module::Metadata docs say not to use
+	# package_versions_from_directory() directly, but the 'files =>'
+	# version of provides() is broken, and has been known to be so
+	# since 2014, so it's not getting fixed any time soon. So:
+
+	foreach my $fn ( sort keys %{ $manifest } ) {
+	    $fn =~ m/ [.] pm \z /smx
+		or next;
+	    my $pvd = Module::Metadata->package_versions_from_directory(
+		undef, [ $fn ] );
+	    foreach my $pkg ( keys %{ $pvd } ) {
+		$meta->should_index_package( $pkg )
+		    and $meta->should_index_file( $pvd->{$pkg}{file} )
+		    and $provides->{$pkg} = $pvd->{$pkg};
+	    }
 	}
 
 	1;
